@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2012  Otfried Cheong
+    Copyright (C) 1993-2013  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -161,8 +161,10 @@ protected:
 
   CanvasBase *iCanvas;
 
+  std::vector<int> iScalings;
   String iCoordinatesFormat;
   int iMouseIn;
+  double iMouseFactor;
 };
 
 // --------------------------------------------------------------------
