@@ -45,14 +45,15 @@ static int traceback (lua_State *L)
 {
   if (!lua_isstring(L, 1))  /* 'message' not a string? */
     return 1;  /* keep it intact */
-  lua_getfield(L, LUA_GLOBALSINDEX, "debug");
+  lua_rawgeti(L, LUA_REGISTRYINDEX, LUA_RIDX_GLOBALS);
+  lua_getfield(L, -1, "debug");
   if (!lua_istable(L, -1)) {
-    lua_pop(L, 1);
+    lua_pop(L, 2);
     return 1;
   }
   lua_getfield(L, -1, "traceback");
   if (!lua_isfunction(L, -1)) {
-    lua_pop(L, 2);
+    lua_pop(L, 3);
     return 1;
   }
   lua_pushvalue(L, 1);    // pass error message
