@@ -498,7 +498,7 @@ int PMenu::add(lua_State *L)
 		    "argument is not a function or string");
       current = checkstring(L, 6);
     }
-    int no = lua_objlen(L, 4);
+    int no = lua_rawlen(L, 4);
     QMenu *sm = new QMenu(title, iMenu);
     for (int i = 1; i <= no; ++i) {
       lua_rawgeti(L, 4, i);
@@ -927,7 +927,8 @@ static const struct luaL_Reg ipeui_functions[] = {
 
 int luaopen_ipeui(lua_State *L)
 {
-  luaL_register(L, "ipeui", ipeui_functions);
+  luaL_newlib(L, ipeui_functions);
+  lua_setglobal(L, "ipeui");
   luaopen_ipeui_common(L);
   return 0;
 }
